Enum bitstream_io::huffman::HuffmanTreeError [−][src]
pub enum HuffmanTreeError {
InvalidBit,
MissingLeaf,
DuplicateLeaf,
OrphanedLeaf,
}Expand description
An error type during Huffman tree compilation.
Variants
One of the bits in a Huffman code is not 0 or 1
A Huffman code in the specification has no defined symbol
The same Huffman code specifies multiple symbols
A Huffman code is the prefix of some longer code