[−][src]Enum bitstream_io::huffman::HuffmanTreeError
An error type during Huffman tree compilation.
Variants
InvalidBitOne of the bits in a Huffman code is not 0 or 1
MissingLeafA Huffman code in the specification has no defined symbol
DuplicateLeafThe same Huffman code specifies multiple symbols
OrphanedLeafA Huffman code is the prefix of some longer code