Trait HuffmanRead

trait HuffmanRead<E: Endianness>

A trait for anything that can read Huffman codes of a given endianness from an input stream

Required Methods

fn read_huffman<T>(self: &mut Self, tree: &[ReadHuffmanTree<E, T>]) -> Result<T>
where
    T: Clone

Given a compiled Huffman tree, reads bits from the stream until the next symbol is encountered.

Errors

Passes along any I/O error from the underlying stream.

Implementors