Struct bitstream_io::write::ByteWriter [−][src]
pub struct ByteWriter<W: Write, E: Endianness> { /* fields omitted */ }
For writing aligned bytes to a stream of bytes in a given endianness.
This only writes aligned values and maintains no internal state.
Implementations
Wraps a ByteWriter around something that implements Write
Wraps a BitWriter around something that implements Write
with the given endianness.
Unwraps internal writer and disposes of ByteWriter.
Any unwritten partial bits are discarded.
Converts ByteWriter to BitWriter in the same endianness.